@@ -383,8 +383,10 @@ type Options struct {
 	EnableCodeTemplates bool
 	// DisableUnsignedTemplates disables processing of unsigned templates
 	DisableUnsignedTemplates bool
-	// EnableSelfContainedTemplates disables processing of self-contained templates
+	// EnableSelfContainedTemplates enables processing of self-contained templates
 	EnableSelfContainedTemplates bool
+	// EnableGlobalMatchersTemplates enables processing of global-matchers templates
+	EnableGlobalMatchersTemplates bool
 	// EnableFileTemplates enables file templates
 	EnableFileTemplates bool
 	// Disables cloud upload
